text1 stringlengths 2 269k | text2 stringlengths 2 242k | label int64 0 1 |
|---|---|---|
Would like to request support for the following image format (loading,
saving). Support for image _data, metadata (Exif/XMP)_ , and all other
features.
High Efficiency Image File Format (HEIF) - [Based on H.265 video codec]
|
This is a feature request, not a bug.
##### Detailed description
https://github.com/strukturag/libheif
I'd like to access HEIF files directly without conversion. Is it possible to
add a build flag by using libheif?
| 1 |
There's a pretty obscure coding language out there called Sourcepawn, and I've
recently released a language package for it. The only problem now is that both
Sourcepawn and PHP use the `.inc` file type. I didn't include a
`firstLineMatch` for the Sourcepawn package because there's really no telling
what someone will ... |
I will explain this issue referring to a third–party package, although the
problem _might_ be realted to atom's grammar auto detection feature:
Cucumber package for Gherkin syntax and step definitons
(https://github.com/edda/cucumber-atom/) defines two grammars:
1. Gherkin (file types: `feature`)
2. Cucumber St... | 1 |
(Reported by internal user)
## 🐛 Bug
I'm observing some weird behaviors with the sparse mode of nn.Embedding. For
instance, with the following code:
m = nn.Embedding(10, 3, sparse=True)
m.zero_grad()
m(torch.LongTensor([7, 1, 3])).sum().backward()
print(m.weight.grad)
I'll get
... |
I'm observing some weird behaviors with the sparse mode of nn.Embedding (both
in PyTorch 0.4 and 1.0). For instance, with the following code:
m = nn.Embedding(10, 3, sparse=True)
m.zero_grad()
m(torch.LongTensor([7, 1, 3])).sum().backward()
print(m.weight.grad)
I'll get
torc... | 1 |
## Steps to Reproduce
Can not reproduce problem myself, however I'm having multiple crashes reported
in Google Play console from several users. The problem is only happens on
Android 4.4
## Logs
signal 11 (SIGSEGV), code 1 (SEGV_MAPERR)
libhoudini.so
*** *** *** *** *** *** *** *** *** *... |
## Steps to Reproduce
1.use simplest demo,set ndk in build.gradle,designated cpu to `armeabi-v7a`
ndk {
abiFilters "armeabi-v7a"
}
2. run the app on yeshen simulator(夜神模拟器),which one is arm cpu type
3. the app is crash
## Logs
01-27 10:57:0... | 1 |
let i: u8 = -1
Replacing -1 by 256 gives the following warning:
literal out of range for its type
This could also apply to the code above. Unfortunately even an explicit cast
to u8 doesn't remove the second warning.
Note that clang has a related warning:
warning: im... |
Generic code should produce the same code as their monomorphic counterparts.
However, a lot of additional `nop` are produced on generic code. For example:
#[inline(never)]
fn doit_not_generic(a: f32) -> f32 {
let mut a = a;
do 1000000000.times {
a = a * a;
}
... | 0 |
I'm setting up what (I think) should be a straightforward image loading
pipeline:
decoded_image = tf.image.decode_jpeg(value)
resized_image = tf.image.resize_image_with_crop_or_pad(decoded_image, width, height)
However, I get an error `'image' must be fully defined.` \- the image not
being fully d... |
Because `tf.image.resize_image_with_crop_or_pad()` requires its input to have
a fully defined shape, it's not useful as part of an input pipeline since the
size of images loaded will not be known in advance.
queue = tf.train.string_input_producer(filenames)
reader = tf.WholeFileReader()
_... | 1 |
This is with devel as of `61d283e`
$ cat test.yaml
- name: derp
hosts: localhost
gather_facts: no
connection: local
tasks:
- name: derp
command: echo
$ ansible-playbook -i foo.com, test.yaml -vv
PLAY [derp] ***************************... |
##### ISSUE TYPE
* Bug Report
##### COMPONENT NAME
docker_container
##### ANSIBLE VERSION
ansible 2.3.0.0
config file = /home/marcel/Projects/foo/ansible.cfg
configured module search path = Default w/o overrides
python version = 2.7.12 (default, Dec 4 2017, 14:50:18) [GCC 5.4.0... | 0 |
I know the protected vs. private debate has been coming up several times
already, yet my question: is there a reason not to make the `Filesystem`
components `toIterator()` method `protected`? I'd like to extend the class in
one project and keep the concept of allowing strings, arrays or any
Traversables to be passed.... |
There are quite a number of dependencies in symfony/framework-bundle that
should be optional.
1. symfony/asset
Don't need it when building an app without GUI.
2. symfony/security-core
Don't need when I don't want to include any sort of access control
3. symfony/security-csrf
Don't need it unless I have fo... | 0 |
##### Issue Type:
Bug Report
##### Ansible Version:
ansible 1.6.10
##### Environment:
Running: OS X
Managing: Ubuntu 13.10
##### Summary:
Running the `GATHERING FACTS` command can cause an exception and print a
traceback if the managed server is out of disk space.
##### Steps To Reproduce:
Set up a server ... |
##### Issue Type: Bug Report
##### Ansible Version: ansible 1.8.4
##### Ansible Configuration: Nothing
##### Environment: Darwin redacted 14.4.0 Darwin Kernel Version 14.4.0: Thu
May 28 11:35:04 PDT 2015; root:xnu-2782.30.5~1/RELEASE_X86_64 x86_64
##### Summary:
When resolving a variable from `another_host` via ... | 0 |
@mdo Two suggestions for the upcoming version:
1. A page similar to http://html5up.net/twenty (click to slide within page)
2. ~~A Gmaps page. (this actually is more important as many people have to figure out how to combine the libraries together)~~
Thanks! :)
|
Template based off of example here:
http://twitter.github.com/bootstrap/examples/fluid.html
If a `href` attribute is added to the anchor tag in the `.hero-unit`, the
button text color ends up being `#666` instead of white.
| 0 |
* I have searched the issues of this repository and believe that this is not a duplicate.
* I have checked the FAQ of this repository and believe that this is not a duplicate.
### Environment
* Dubbo version: 2.7.2
* Operating System version: mac
* Java version: JDK8
### Steps to reproduce this issue
... |
### Environment
* Dubbo version: 2.7.1
* Dubbo Admin version: 0.2.0
* Java version: 1.8
### Steps to reproduce this issue
在dubbo-admin中添加权重设置和负载均衡设置
在zookeeper里面能看到设置的结果在config下面

 lives in the bin directory there, but breaks on *nix
because there it lives in a `lib` director... |
It would be great if there are methods to get `CFLAGS` and `LDFLAGS` to link
against `libjulia`. In R, there are
`R CMD config` to get `CPPFLAGS` and `LDFLAGS`. So far, I can only find
`JULIA_HOME`.
| 1 |
FYI. we should add a secret manager to store the pull secrets for different
namespaces. Thus for duplicate secrets, we have no need to talk to api server.
Actually I am working on this manager, but I have no idea about when to remove
a secret.
|
**Is this a request for help?** (If yes, you should use our troubleshooting
guide and community support channels, see
http://kubernetes.io/docs/troubleshooting/.):
**What keywords did you search in Kubernetes issues before filing this one?**
(If you have found any duplicates, you should instead reply there.):
* * ... | 0 |
I ran into a bug today where including angular2.min.js would result in my code
failing but using angular2.js would run fine.
Example plunkr here: http://plnkr.co/edit/599t9vXIoDWvERnvCTWu?p=preview
In it's current state the [(ngModel)] bind fails so the text box gets no data,
but if you switch the page to load angu... |
When using minified bundles with SystemJS, and a simple snippet like this
<template ngFor #item [ngForOf]="items" #i="index">
<li>{{i}}</li>
<li *ngIf="i % 2 == 0">number is even</li>
</template>
Will throw
TypeError: this.directive_0... | 1 |
**Symfony version(s) affected** : 4.3
**Description**
URL parsing fails. For example:
`https://nova.laravel.com/password/reset`
This resolves correctly.
However `https://nova.laravel.com//password/reset` this results in a 404.
Which could be seen as a user error.
But `https://nova.laravel.com//foobar/pass... | Q | A
---|---
Bug report? | no
Feature request? | yes?
BC Break report? | no
RFC? | no
Symfony version | all
I am working on application which define different route parameters depending
on subdomain (for simplicity lets call them languages)
For example there are `en`, `pl`, `gb` sub domains. Which ma... | 0 |
I have two GPUs installed, with the same script, if I select to run on RTX
2080 Ti, the error occurs, and if I run on GTX 1080 Ti, it works right.
`~/Molecule_Optimizer.py in forward(self, atom_list, bond_list,
atom_degree_list, bond_degree_list, atom_mask)
33 atom_mask = atom_mask.unsqueeze(2)
34 batch_size,mol... |
## 🚀 Feature
Now the Pytorch cannot support cuda10 directly, so it cannot be run on RTX
series GPUs
## Motivation
Just wanna get the Pytorch run on my RTX 2080ti asap, thx
| 1 |
**Do you want to request a _feature_ or report a _bug_?**
Request a feature
Per some discussion today with @tomocchino and @thejameskyle, I'd like a non-
Flow mechanism to annotate what type(s) of elements a component expects to
render.
Here's some examples, with Flow types for comparison (that I realize may not... |
_feature_
> Warning: A component is `contentEditable` and contains `children` managed by
> React. It is now your responsibility to guarantee that none of those nodes
> are unexpectedly modified or duplicated. This is probably not intentional.
It would help heaps if I would know _which_ component is causing this.
| 0 |
Hi, we've prepared ourselves for angular2 a while, and decided to use the RC1
version for our new projects. But RC1 is loading hundreds of javascript files.
Is this a feature mean to be? Or it will be solved soon? About when?
Thank you for your attention.
|
**Steps to reproduce and a minimal demo of the problem**
create a new A2RC1 app with angular-cli:
ng new blah
cd blah
npm start
load the page with your dev tools open and observe that it submits over 290
xhr requests at startup. beta-14 (from which we just upgraded) loads about 40.
**C... | 1 |
The xml package embeds the fields of an anonymous field type onto the outer structure's
XML element. Currently this isn't supported for pointer types though. This should be
fixed.
|
http://blog.golang.org/2011/06/profiling-go-programs.html doesn't use the Go 1 'go' tool.
Update this blog post?
Noted from http://bpowers.github.com/weblog/2013/01/05/optimizing-real-world-go/
| 0 |
Where did `col-*-push-12` classes go? Is there a new way to swap `col-*-12`
elements?
I vaguely remember this used to work at some point:
<div class="col-sm-12.col-sm-push-12">a</div>
<div class="col-sm-12.col-sm-pull-12">b</div>
rendered
b
a
|
I have am using an accordion to display a series of images in carousels, The
accordions seem to be working but when I try and open a carousel in one of the
accordions they don't size to the area of the carousel. I tried to specify
sizes looking at them with firebug and have been unsuccessful. Any suggestions
on how t... | 0 |
* I have searched the issues of this repository and believe that this is not a duplicate.
## Expected Behavior
elements should be aligned horizontally with homogenous margins/paddings by
default in all browsers.
## Current Behavior
It's pretty hard to align intput elements horizontally because they have
varying... |
In the olde version Button had a fullWidth. The textFields have also a
fullWidth.
* I have searched the issues of this repository and believe that this is not a duplicate.
## Expected Behavior
The Button needs to have a fullWidth option.
Example: `<Button fullWidth>Logion</Button>`
## Current Behavior
do... | 0 |
A common way to strip double-quotes from a variable in Windows Batch Language:
set my_var=%my_var:"=%
But, VS code syntax highlighter thinks that the double-quote in the line above
is starting a string, and so, it highlights all code in the file beyond that
double-quote until it finds another double-quote in t... |
After upgrading to version 0.10.1 Syntax highlighting within windows .bat
files has become reduced.
Previous versions would syntax highlight variables (%VARIABLENAME%) and
comments(REM-COMMENT TEXT" now these both appear as normal text:
{
var Child = something? A : B;
return (
<Child />
)
}
* Toggle CSS Display is simple
className={this.props.shouldHide ? 'hidden' : ''}
| 1 |
### Problem description
I'm getting the followinig warning when I use the closeIcon property on a
CardTitle:
> Warning: Unknown prop `closeIcon` on
>
> tag. Remove this prop from the element. For details, see
> https://fb.me/react-unknown-prop
However, the element is working just fine, the icon is being displayed ... |
### Problem description
When using the `closeIcon` prop on CardTitle, the selected icon is displayed
but a warning that the prop is passed to a `div` is displayed in the console.
### Link to minimal working code that reproduces the issue
https://www.webpackbin.com/bins/-Kjal6iMWuKp0Lg-1DB9
### Versions
* Mater... | 1 |
Hi,
Running the example, using a custom Document (with-styled-components) I
noticed that the stylesheets are being added in duplicate to the page.
Apparently flushing the stylesheets like we're doing here avoids this issue
but raises a total different one (FOUC).
Any idea why the stylesheets are being added more t... |
* I have searched the issues of this repository and believe that this is not a duplicate.
## Expected Behavior
A method in router API that allows aborting upcoming route change.
## Current Behavior
Right now router exposes `abortComponentLoad` method but it seems to be
designed only for internal use and it does... | 0 |
Hello,
I did
import numpy as np
import pandas as pd
from matplotlib.pyplot as plt
idx = pd.date_range('20140101', '20140201')
df = pd.DataFrame(index=idx)
df['col0'] = np.random.randn(len(idx))
s_idx = pd.Series(idx, index=idx) # need to do this because we can't shift inde... |
#### Code Sample
import pandas as pd
from pandas.compat import StringIO
import matplotlib.pyplot as plt
dat = """c1,c2,c3
1000,2000,1500
9000,8000,1600"""
df = pd.read_csv(StringIO(dat))
print(df)
df.plot.bar()
plt.show()
df = df.app... | 1 |
I am aware try-catch is emitted in 'for of' for some compatibility reason;
however, it can be a surprising performance-hit on eg V8. Is there a way to
suppress its emission (at the cost of some compatibility)?
|
### 💻
* Would you like to work on a fix?
### How are you using Babel?
Programmatic API (`babel.transform`, `babel.parse`)
### Input code
({
__proto__: a,
__proto__: a,
a: a = 1
})
REPL
### Configuration file name
_No response_
### Configuration
N. A.
### Current and e... | 0 |
# Dynamic Routes
## Background
Dynamic routing (also known as URL Slugs or Pretty/Clean URLs) has been a
long-time requested feature of Next.js.
Current solutions involve placing a L7 proxy, custom server, or user-land
middleware in-front of your application. None of these solutions offer a
sufficiently _ergonomic... |
Currently I am working on an i18n solution with my nextjs app. In general I
don't want to include all the text strings with the initial page load.
Especially with huge pages (think of wikipedia or a terms and condition page).
All those text strings are already part of the server side rendered document.
Why include it... | 0 |
I started to give error "writebarrierptr_nostore1" without any stack after
compilation of my app "https://github.com/vsdutka/iplsgo" with Go 1.5 and
stress it by 400 concurent requests.
OS: Windows Server 2008 R2 Standart 64bit
|
This looks a lot like #11863
Stack trace:
found next stack barrier at 0xc857445a00; expected [*0xc8427059f0=0x869015 *0xc842705e38=0x61b1de]
fatal error: missed stack barrier
goroutine 0 [idle]:
runtime.throw(0xcb8fc0, 0x14)
/root/.gvm/gos/go1.5.1/src/runtime/panic.go:527 +0x9... | 1 |
With Julia 0.4.0-dev, the input `"a" "b"` in the REPL leads to the output
`"a"` instead of a string concatenation or an error. The second string `"b"`
is silently discarded.
|
I would suggest that new syntax "a..b" represents "[a, a+1, a+2, ... , b]".
The followings should then become true:
"1..5" represents "[1, 2, 3, 4, 5]".
"reverse(1..5)" represents "[5, 4, 3, 2, 1]".
"1..99[1:2:end]" represents "[1, 3, 5, 7, ..., 99]".
Related issue: #3737
| 0 |
I have been attempting to switch my Future / Stream lib to use associated
types, however I have been hitting snags. Even though all the types (as far as
I can tell) are bound by Send (and some by 'static too), I have been getting a
lot of error messages:
/Users/carllerche/Code/mine/syncbox/src/util/asy... |
Take this code:
trait Foo { type Value: 'static; }
fn require_static<T: 'static>() {}
fn takes_foo<F: Foo>() {
require_static::<F::Value>()
}
Since `Foo::Value` is bounded with `'static`, we would expect this to compile,
but instead we get this error message:
... | 1 |
## Feature
As the subject says it will be great if `np.fill_diagonal` had a k-ith
diagonal argument as `np.diag` does. The behavior expected (and a hack for the
solution) is better explained in the following StackOverflow question by me
## Expected behaviour
>>> u = np.zeros(25).reshape(5, 5)
>>>... |
It would be really nice if `np.fill_diagonal` could fill other diagonals
besides the main diagonal. This would match the `offset` argument of
`np.diagonal.`
Shouldn't require much code to allow this.
| 1 |
I tried to solve the eigenvalues and eigenvectors of a Hermitian matrix, the
code used to work nicely and still works in Cocalc, but not on my windows 10
(the system got some updates) now, and the error is very confusing, I can not
figure out what is happening now, maybe someone also has a similar issue.
Python vers... |
Add support for the LDL decomposition, which is a variant of the Cholesky
decomposition that doesn't take any square roots (faster). LAPACK has a
function for this called DPTTRF, so I'm guessing that supporting this is just
a matter of adding a wrapper for this function. Also, if this is something
that would fit bett... | 0 |
**Floyd** opened **SPR-9266** and commented
I am not sure if any one has raised this concern before.
I saw this in StackOverflow :
http://stackoverflow.com/questions/8417232/spring-delegatingfilterproxy-multi-
threading-concerns
Running in high load, the "synchronized (this.delegateMonitor)" in the
"doFilter" met... |
**Yury Lapko** opened **SPR-10413** and commented
Unnecessary thread blocking occurs every time when the method doFilter is
called. Can be used double check locking to avoid unnecessary thread blocking.
* * *
**Affects:** 3.2.2
**Reference URL:** https://github.com/SpringSource/spring-
framework/blob/3.2.x/sprin... | 1 |
**I'm submitting a ...** (check one with "x")
[ ] bug report => search github for a similar issue or PR before submitting
[x] feature request
[ ] support request => Please do not submit support request here, instead see https://github.com/angular/angular/blob/master/CONTRIBUTING.md#question
... |
**I'm submitting a ...** (check one with "x")
[x] bug report => search github for a similar issue or PR before submitting
[ ] feature request
[ ] support request => Please do not submit support request here, instead see https://github.com/angular/angular/blob/master/CONTRIBUTING.md#question
... | 0 |
Executing same code in 2 machines
Python 3.6.5
numpy==1.14.4
and
Python 3.7.6
numpy==1.17.3
the time it takes in 1.14 is near 3 times faster. Downgrading to 1.14 from
1.17 confirms it:

You may need an appropriate loader to handle this file type, currently no loaders a... | 0 |
_Please make sure that this is a bug. As per ourGitHub Policy, we only
address code/doc bugs, performance issues, feature requests and
build/installation issues on GitHub. tag:bug_template_
**System information**
* Have I written custom code (as opposed to using a stock example script provided in TensorFlow):
... |
_Please make sure that this is a bug. As per ourGitHub Policy, we only
address code/doc bugs, performance issues, feature requests and
build/installation issues on GitHub. tag:bug_template_
**System information**
* Have I written custom code (as opposed to using a stock example script provided in TensorFlow):
... | 1 |
### Input Code
let a: string = 'a';
(<any>a) = null;
### Babel/Babylon Configuration (.babelrc, package.json, cli command)
{
sourceType: 'module',
plugins: [
'typescript',
],
}
### Expected Behavior
no error
### Current Behavior
ERR .... |
### 💻
* Would you like to work on a fix?
### How are you using Babel?
Other (Next.js, Gatsby, vue-cli, ...)
### Input code
https://codesandbox.io/s/bold-pond-g5nzv
### Configuration file name
_No response_
### Configuration
_No response_
### Current and expected behavior
If you will try to check exa... | 0 |
I setup my laptop so that my day to day work is not in an admin account. For
most software, when comes upgrade time, all I have to do is enter the admin
account login and password when prompted and I can proceed. This is not the
case with Atom. Everytime I want to upgrade, I have to manually download Atom
and replace... |
I've never been able to get the autoupdate to work. It detects a new version,
happily downloads, but when I click restart and update, it quits the app,
presumably fails to update, and then relaunches, and starts redownloading the
update. Usually then I have to get into a hit-quit-a-bunch-war to get it to
stop relaunc... | 1 |
## ❓ after pytorch Stable(1.5) installation on macOS Catalina
* python 3.8
* pytorch Stable(1.5)
## error
ImportError: dlopen(/Library/Frameworks/Python.framework/Versions/3.8/lib/python3.8/site-packages/torch/_C.cpython-38-darwin.so, 2): Library not loaded: @rpath/libc++.1.dylib
Referenced... |
## 🐛 Bug
Install on MacOS fails with pip.
## To Reproduce
(venv) ➜ whatlies git:(master) ✗ python -m pip install torch
(venv) ➜ whatlies git:(master) ✗ python
Python 3.7.7 (v3.7.7:d7c567b08f, Mar 10 2020, 02:56:16)
[Clang 6.0 (clang-600.0.57)] on darwin
... | 1 |
This code worked before:
function A () { let a }
function B () { let a }
Now I get a TypeError:
TypeError: foo.js: Line 2: Duplicate declaration "a"
1 | function A () { let a }
> 2 | function B () { let a }
| ^
3 |
at File.errorWi... |
So to test `babel`, I ran a bunch of commands:
mkdir babel-test
cd babel-test
echo "export async function foo(){}" > src.js
echo "{ \"presets\": [ \"es2015\", \"stage-0\" ] }" > .babelrc
npm i babel-cli@latest -g
npm i babel-preset-es2015@latest
npm i babel-preset-stage-0@latest... | 0 |
Challenge change-styles-based-on-data has an issue.
User Agent is: `Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML,
like Gecko) Chrome/57.0.2987.110 Safari/537.36`.
Please describe how to reproduce this issue, and include links to screenshots
if possible.
It isn't the particular challenge but more so ... |
The last 2-3 days my activity calendar is blank. It shows no activity although
it says i have completed 217 items so far.
When i open chrome's console it has an error that might help in solving the
problem which says "Uncaught TypeError: Cannot read property 'getTime' of
undefined".
I tried to open the page with f... | 0 |
I want add an element to the top of the LeftNav which contains the user's
picture and name, but it seems like all that I can specify are menu items. I
don't see how I can have complicated content inside MenuItems from the
examples.
Any guidance of what I should do?
|
Is there a way to make the LeftNav component composable? I need to add a
custom component into the LeftNav. Is there a way to add another MenuItemType
or pass in children into the render function on the LeftNav?
| 1 |
Describe what you were doing when the bug occurred:
1.
2.
3.
* * *
## Please do not remove the text below this line
DevTools version: 4.2.0-a8b8ffb89
Call stack: at n.value (chrome-
extension://fmkadmapgofadopljbjfkapdkoienihi/build/main.js:40:162685)
at m (chrome-
extension://fmkadmapgofadopljbjfkapdkoie... |
**In React 15** , `ComponentWillUnmount` called first before the rendering of
next component in DOM. **In the current version (v16)** ,
`ComponentWillUnmount` was called after the mounting of next component.
It creates an issue with my existing code, since I reuse the same component
after the history changes so it ... | 0 |
Ambient class declarations implementing an interface require the user to
repeat the type members declared in the interface.
For example with the interface
interface IFoo {
bar: string;
qux(): number;
}
an ambient declaration of `Foo` as
declare class Foo implements ... |
http://typescript.codeplex.com/workitem/1125
Following should be allowed:
interface IFoo {
foo();
}
declare class Foo implements IFoo {}
If abstract classes are added in the future, they would inherit all interface
methods as abstract (like in Java).
| 1 |
I added some input textboxes and buttons with a very long dropdonw menus.
Then I put them into a div that is in a narrow Collapse or Togglable tabs.
But the dropdown menus cannot display whole menus. The menus was cut off by
the region of div.
How to let the dropdown menu display out of the parent div?
Because... |
I'm running the latest version of bootstrap (2.0.3) and there appears to be a
clipping problem when I place a dropdown into tabbed content. I see that this
was resolved in version 2.0.2 (#2079) where the overflow:hidden was changed to
display: table.
.tab-content {
display: table; // prevent content from running b... | 1 |
When tapping a image (i.e. hero) that is below the app bar, the hero animation
immediately places it on top (this particular animation is not so bad). When
pressing the back button, the moment when the app bar comes back on top is
late an noticeable, making the animation look janky.
|
Open Gallery, open pesto, scroll up enough to minimize the app bar. Tap a
recipe.
Notice how the app bar immediately disappears, before the recipe begins its
motion up. This is a jarring effect that the user could notice.
We could try something more subtle, like animating or fading the app bar away
as the recipe op... | 1 |
It would be very convenient to have `SAME` padding supported for convolutional
layers
|
The implementation would be easy, but could help many people suffered from the
headache of calculating how many padding they need.
cc @ezyang @gchanan @zou3519 @bdhirsh @jbschlosser @albanD @mruberry
@walterddr
| 1 |
### Is there an existing issue for this?
* I have searched the existing issues
### This issue exists in the latest npm version
* I am using the latest npm
### Current Behavior
WinOS
### Expected Behavior
_No response_
### Steps To Reproduce
1. In this environment...
2. With this config...
3. Run '.... |
### Is there an existing issue for this?
* I have searched the existing issues
### This issue exists in the latest npm version
* I am using the latest npm
### Current Behavior
OS name: WinOS
OS version: Microsoft Windows [Version 10.0.19044.2486]
node v18.6.0
npm v9.3.0
I ran into an _ugly_ bug when t... | 1 |
The first time I build an app, `flutter run` just seems to hang after giving
some obscure error message (something from FlutterDynamicsServiceLoader.mm).
Eventually though (after I have up waiting) it completes and everything is
fine.
We should make it faster.
We should also give progress while it's doing whatever ... |
## Steps to Reproduce
On the iOS simulator...
flutter create new-project
cd new-project/
flutter run
Wait 1 minute and nothing has occurred. The app icon is not present on the
simulator.
## Flutter Doctor
[✓] Flutter (on Mac OS, channel master)
• Flutter at /Users... | 1 |
I'm trying to parametrize mlab tests (which cuts out many many lines of
classes), but there are a few differences between similar tests which makes it
really difficult to parametrize things (e.g., real vs. complex). Here are some
differences:
* Between real and complex:
* `len_x` differs in:
* `nosig_d... |
### Bug summary
THIS IS NOT A POST FOR COMMUNITY HELP.
THIS IS A BUG REPORT.
PLEASE DO NOT CLOSE BEFORE REPLICATION.
### Code for reproduction
%matplotlib ipympl
import numpy as np
import matplotlib.pyplot as plt
import matplotlib.animation as animation
import time
fig... | 0 |
When using globs in ES6 template strings, VSCode's syntax highlighting thinks
there is a unclosed comment. Example: `${settings.tests}**/*.js`

Notice that after the /* all coloring is green, until the nex... |
Right now, those keywords like `import` `class` `from` are all plain white.
| 1 |
A call to `mapslices` that takes a `dims` argument is type unstable. This is
the case in all recent versions of Julia (1.1.1, 1.2.0, 1.3.1, 1.4.2).
For example:
d = rand(10)
mapslices(identity, d; dims=1)
Shows the following with `@code_warntype`:
Variables
#unused#::Core.Com... |
Consider the following piece of code:
n=10^6;
X = randn(1,n);
V(x) = 0.5 * dot(x,x);
f(V, X) = [ V((@view X[:,n])) for n = 1:size(X,2) ]
Timing on this reveals:
julia> @time mapslices(V, X, 1);
1.177690 seconds (12.00 M allocations: 267.024 MiB, 6.91% gc time)
... | 1 |
I started seeing a few weeks ago a spurious (~25-50% of the time) CI failure
in GithubActions on MacOs runners.
I have been unable to reproduce it on my local (Mac) computer.
I have been able to pinpoint this to `jaxlib==0.1.68`. Downgrading to
`jaxlib==0.1.67` with current jax==0.2.16` makes the issue disappear.
... |
Hi. This is a bit of a strange (possible) bug report that we've held off on a
for a few days until we could try to get better reporting information. Both
`pyhf` and `awkward` have been seeing segfaults on GitHub Actions jobs (for
`pyhf`) and Azure Pipelines jobs (for `awkward`) since the release of `jaxlib`
`v0.1.68`... | 1 |
A (personal) user experience:
While looking for matching functionality on `str`, I went to the following
link:
* `mod str`: https://doc.rust-lang.org/std/str/index.html
* note that this is distinct from primitive `str`: https://doc.rust-lang.org/std/primitive.str.html
* you may not realize that at first gla... |
There are a number of problems with our current quote_expr!, quote_tokens!,
etc. macros. The first one is that they're cloaking/unhygienic. Fixing this is
easy--just change the macro definition so that you have to supply an
identifier as the first argument.
The second problem is that they really shouldn't work in th... | 0 |
I've just tried using the customised download facility to create me a
Bootstrap v2.0 stylesheet by specifying only the colours I required to be
different from the core Bootstrap definitions. However, this is how my app's
coming out looking like when using the bundled **bootstrap.min.css** file:

print(f"unexpected: {x}") # unexpected: 101.0999984741211
print(f"expected str: {x!s}") # expected str: 101.1
print(f"expected repr: {x!r}") # expe... |
### Describe the issue:
This could be related:
pypa/setuptools#3197 (comment)
Latest numpy release (1.22.3) cannot build from source when using latest
setuptools.
### Reproduce the code example:
python3 -m pip install -Uv setuptools==61.3.1
python3 -m pip install -Uv git+https://github.com/num... | 0 |
**Note:** I know this issue already exists in raised issue but I found it
unresolved. Please don't close it as I included troubleshooting suggested by
other threads too along with all outputs and snapshots. so its not a duplicate
issue.
I am using Windows 8.1 64bit
having 7z and git installed on my system
envir... |
flutter: ══╡ EXCEPTION CAUGHT BY WIDGETS LIBRARY ╞═══════════════════════════════════════════════════════════
flutter: The following assertion was thrown building ExpansionPanelList:
flutter: 'package:flutter/src/material/mergeable_material.dart': Failed assertion: line 443 pos 18:
flutter: '... | 0 |
##### System information (version)
* OpenCV => 4.2.0
* Operating System / Platform => Windows 7 64 Bit
* Compiler => Visual Studio 2017
##### Detailed description
##### Steps to reproduce
1.I use VS2017, C ++/MFC/Win32 project。When I quit the program, I found a
memory leak。
Detected memory leaks!
Dumpin... |
##### System information (version)
OS: Ubuntu 18.04 bionic
Kernel: x86_64 Linux 4.18.8-041808-generic
Uptime: 26m
Packages: 3341
Shell: bash 4.4.19
Resolution: 3840x1080
DE: Budgie
WM: BudgieWM
WM Theme: Adwaita
GTK Theme: Adwaita [GTK2/3]
Icon Theme: Adwaita
Font: Ubuntu 11
CPU: Intel Core i... | 0 |
On the Dashboard example there is a typo in the dashboard.css under the "Main
Content" section.
@media (min-width: 768px) {
.main {
padding-left: 40px;
pading-right: 40px; <---- Change to padding-right
}
}
|
@@ File: examples/dashboard/dashboard.css
@@ Line: 69 // pading- => padding-
@media (min-width: 768px) {
.main {
padding-left: 40px;
* pading-right: 40px;
* padding-right: 40px;
}
}
| 1 |
### Background
The most important thing about specifying analyzers is the analyzer used at
index time needs to be basically the same as the analyzer used at query time.
If completely different analyzers were to be used, you would either produce
terms that could never be found at query time, or query for terms that c... |
## ES with Multi-Cluster Search Support
It'd be nice to be able to query across multiple clusters and get their
aggregated results.
Our initial motivation is to view Kibana results across multiple clusters.
See: Enhancement: Allow conntections to multiple ES backends from a single
Kibana instance.
However, since w... | 0 |
import tensorflow as tf
Traceback (most recent call last):
File "", line 1, in
import tensorflow as tf
File "C:\ProgramData\Anaconda3\lib\site-packages\tensorflow_ _init_ _.py",
line 22, in
from tensorflow.python import pywrap_tensorflow # pylint: disable=unused-
import
File "C:\ProgramData\Anaconda3\lib\sit... |
### System information
* **Have I written custom code (as opposed to using a stock example script provided in TensorFlow)** : No
* **OS Platform and Distribution (e.g., Linux Ubuntu 16.04)** : Linux Ubuntu 16.04
* **TensorFlow installed from (source or binary)** : source
* **TensorFlow version (use command b... | 0 |
It would be great when I want to perform a Quick Open on a file that VSCode
would search as I type. Atom and Sublime do this and it makes finding files so
much easier.
|
Ubuntu 12.04, vscode 0.10.1
I have found Go to file's indexing against a full Chromium workspace to be
very slow. It took ~40 seconds to find "Tab.java" whereas a simple `find`
command took less than a second:
$ time find . -name "Tab.java"
./chrome/android/java/src/org/chromium/chrome/browser/tab... | 1 |
The following code:
pub fn handle(_data: &[u8]) {}
pub fn handle_opt(iter: &mut Iterator<Item = &[u8]>) {
for data in *iter {
handle(data);
}
}
give the following LLVM assert error:
$ rustc --crate-type lib lib.rs
rustc: /home/rustbuild/src/r... |
### Code
fn changer<'a>(mut things: Box<Iterator<Item=&'a mut u8>>) {
for item in *things { *item = 0 }
}
fn main() {
}
### Error
error: internal compiler error: trying to take the sizing type of <core::iter::Iterator + 'static as core::iter::Iterator>::Ite... | 1 |
* Electron version:
0.37.5.
* Operating system:
OSX 10.11.4
I'm using the X509 (https://www.npmjs.com/package/x509)
I followed the instructions here
https://github.com/electron/electron/blob/master/docs/tutorial/using-native-
node-modules.md to but the module is still crashing electron.
npm ... |
Hello, my app uses the native ursa module. I just upgraded to atom-shell
0.23.0, rebuilt the ursa module and now my app is broken. Atom-Shell v0.22.3
was working properly.
Debian Linux x64, io.js@1.5.0, npm@2.7.1, node-gyp@1.0.3
Here's the error I get when I launch my application:
/usr/lib/node_modul... | 1 |
### Environment info
Operating System: CentOS 6.7
If installed from sources, provide the commit hash: `eda89e9`
### Steps to reproduce
1. Configure for gcc 4.8.2
2. ./configure
3. Edit third_party/gpus/crosstool/clang/bin/crosstool_wrapper_driver_is_not_gcc
* This is necessary; otherwise `gcc` can't f... |
I have been trying to compile tensorflow from source without success.
I could compile version 0.6.0 with no trouble, but trying to compile 0.7.1
produces the following error:
> tensorflow/core/kernels/matrix_solve_ls_op.cc: In member function 'void
> tensorflow::MatrixSolveLsOp::ComputeMatrix(tensorflow::OpKernelC... | 1 |
A nice to have feature would be Jest-like snapshot testing in the std/testing
library.
|
It will be easy to understand for contributors or new coming contributors
while looking through the project history.
Conventional commit messages
| 0 |
Upgrading packages...
Running "flutter packages upgrade" in flutter_update_packages_qQnlPY...
! analyzer 0.31.2-alpha.0 from path
/Users/xxx/Documents/GitHub/flutter/packages/flutter_tools/../../bin/cache/dart-
sdk/lib/analyzer
! front_end 0.1.0-alpha.10 from path
/Users/xxx/Documents/GitHub/flutter/packages/fl... |
`flutter update-packages --force-upgrade` fails because intl_translation
package 0.16.1(latest) has upper bound on analyzer package
dependencies:
analyzer: '>=0.29.1 <0.31.0'
but analyzer that comes into flutter with sdk is `0.31.2-alpha.0`
| 1 |
Hi.Is it possible to add a new light after the scene setup?I have a scene and
i want the user to add light in a selected position by pressing a button.I
have tried it and it's not working.
|
HI,
I'm having some difficulty while trying to add a light after some time to the
scene. If the light is created in the init() function there is no issue, but
as soon as you create it later it makes everything look black.
Here is a sample script showing this issue: http://jsfiddle.net/GKCx6/1/
there is a variable ... | 1 |
we are waiting for a long time to see feature like this
http://geedmo.github.io/yamm/
|
i think it will be useful...
| 1 |
* [X ] I have searched the issues of this repository and believe that this is not a duplicate.
## Expected Behaviour
No error in ESLint
Alternatively: Clicking the icon -> expands the card
handleExpandChange = (expanded) => {
^
this.setState({expanded: expanded});
};
Error: Unexpected Token, fatal error... |
* I have searched the issues of this repository and believe that this is not a duplicate.
## Expected Behavior
I was expecting that `body2` type in Typography will use same element as
`body1` which is a `p` element for body1.
## Current Behavior
<Typography type="body1"> Lorem ipsum </Typography> ... | 0 |
### Problem description
When I use `onMouseEnter` and `onMouseLeave` to show a popup (tooltip
behavior), the popup does not appear.
### Link to minimal working code that reproduces the issue
https://codesandbox.io/s/wpjvm86AM
### Versions
* Material-UI: 0.18.2
* React: 15.5.3
* Browser: N/A
I suspect ... |
Hi there,
According to your description of AppBar: "App bars are a collection of
components placed as a static header for an application", I was thinking that
the AppBar wouldn't scroll off the page when you put a long list below it,
let's say. But it does. See this example if you'd like:
http://www.donwoodlock.com... | 0 |
Code:
fn foo(v: &[int]) {
match v {
[_] => {},
[_, ..] => {},
_ => {},
}
}
Wrong error is:
/home/vagrant/tmp2.rs:4:9: 4:16 error: unreachable pattern
/home/vagrant/tmp2.rs:4 [_, ..] => {},
... |
Until friday (commit `3047614`) the following (very contrived) code compiled:
fn main() {
println!("{}", count_members(&[1, 2, 3, 4]));
}
fn count_members(v: &[uint]) -> uint {
match v {
[] => 0,
[_] => 1,
[_x, ..xs] => 1 +... | 1 |
see issue #6873, and https://golang.org/cl/36810043/.
> We already have these in pkg/os, also with this TERRIBLE_CASE. Let's stop the
bleeding.
> In Go 2 we could move them and fix the case or maybe even change the signature to
not be so C-like.
|
When performing a clean build of our project with GO15VENDOREXPERIMENT=1 we
need to run "go install" twice. The first time always fails in cgo-related
compile or link steps. The second time always works fine.
I'm running "go version go1.5beta2 linux/amd64".
The error from cgo is usually different from run to run. I... | 0 |
**Do you want to request a _feature_ or report a _bug_?**
bug
**What is the current behavior?**
My application consists of two parts. The main web application and a module
which gets dynamically loaded into the web application.
Both web application and the module uses React 16.9.0.
The module is loaded into t... |
# To people coming from search: please read this page first. It contains most
common possible fixes!
**Do you want to request a _feature_ or report a _bug_?**
Enhancement
**What is the current behavior?**
I had multiple instances of React by mistake.
When trying to use hooks, got this error:
`hooks can only be... | 1 |
Challenge http://www.freecodecamp.com/challenges/waypoint-make-images-mobile-
responsive` has an issue. Once completed, clicking `Go to my next challenge`
takes you to http://www.freecodecamp.com/challenges/waypoint-manipulate-
arrays-with-push rather than the next challenge.
|
Challenge http://www.freecodecamp.com/challenges/waypoint-sift-through-text-
with-regular-expressions has an issue.
We have this regular expression:
/the+/gi;
And that's how it's explained:
> Let's break this down a bit:
>
> `the` is the pattern we want to match.
> `+` means we want to find ... | 0 |
From @mwarkentin on 2016-03-28T13:51:44Z
##### ISSUE TYPE
* Feature Idea
##### COMPONENT NAME
homebrew
##### DESCRIPTION
It'd be nice if we could use the `brew bundle` command with ansible. Thoughts
on if this should be a new module or included with the existing homebrew
module?
`brew bundle` options:
... |
##### ISSUE TYPE
* Bug Report
##### COMPONENT NAME
network/lldp.py
##### ANSIBLE VERSION
ansible 2.2.2.0
config file =
configured module search path = Default w/o overrides
##### CONFIGURATION
##### OS / ENVIRONMENT
##### SUMMARY
LLDP module fails with a 'str' object does not... | 0 |
Add Flutter to existing apps explains how to use `FlutterViewController` (in
Swift/Objective-C) or `Flutter.createView` (in Kotlin/Java) to create a
Flutter view from an existing native app codebase. When creating a new
view/screen, rarely is the user's activity from that screen going to be
completely isolated from t... |
[This is very similar to http://github.com//issues/15798]
I wanted to open a new issue for this because the issue above is quite
generic. Our clients have been complaining that ability to only send strings
down is too limiting from API point of view. They would love to have
initialRoute (or some similar mechanism) t... | 1 |
Some operations on recarray views of structured arrays leak memory.
### Reproducing code example:
import numpy as np
import resource
# make a random structured array/recarray
arr = np.array(np.vstack(np.random.normal(size=10000000)), dtype=[("x", float), ("y", float)])
rarr = arr.... |
_Original tickethttp://projects.scipy.org/numpy/ticket/1133 on 2009-06-08 by
@rc, assigned to unknown._
This ticket sumarizes the discussion in the numpy mailing list [1], concerning
allowing non-unique arrays as function arguments, better naming conventions
and documentation.
1. the functions with _nu suffix sh... | 0 |
**TypeScript Version:**
actual version on http://www.typescriptlang.org/Playground
**Code**
// A self-contained demonstration of the problem follows...
interface Props {
options: {
name: string | boolean
}
}
let v: Props
if (typeof v.options.name... |
I just found out that property access expressions doesn't work on type
predicate functions and `instanceof` type guards.
class A {
propA: number;
}
class B {
propB: number;
}
class C {
propC: A;
}
declare function isA(p1: any): p1 is D;
... | 1 |

I have 8 gpu's in this machine.

I think its not taking all 8 gpu's. Already tried cha... |
### System Info
- OS Platform and Distribution: Amazon Linux 2
- ONNX version 1.11.0
- Python version: 3.8
- Transformers 4.17
### Who can help?
@LysandreJik, @patil-suraj
### Describe the bug
When I try and convert `microsoft/deberta-v3-large` to onnx format, the file
size doubles to ... | 0 |
As it uses the request attributes it still detects it as the controller set by
the router, if you forward to another controller it only detected as a sub
request and not visible at first glance on the web dev toolbar. It
could/should show any forwarded controllers/sub requests or at least the final
controller that re... |
i keep stumbling over this use case:
https://github.com/liip/LiipFunctionalTestBundle/pull/70/files#L7R25
https://github.com/liip/LiipFunctionalTestBundle/pull/70/files#L1R13
what is the best practice here? is there one? is there something that we could
change to make this easier? specifically i would love to avo... | 0 |
**Migrated issue, originally created by Michael Bayer (@zzzeek)**
poc should allow us to consolidate #2670, #2952, #3149, #3050.
the new descriptors include the ability to cache the result per class, or to
do "cascade", guarantees that the callable fn is called only once per target
class, as well as to name attrib... |
**Migrated issue, originally created by Michael Bayer (@zzzeek)**
test:
from sqlalchemy import *
from sqlalchemy.orm import *
from sqlalchemy.ext.declarative import declarative_base
Base = declarative_base()
class A(Base):
__tablename__ = 'a'
id = Column(... | 0 |
The customize feature (http://twitter.github.io/bootstrap/customize.html)
seems to be broken. I tried a few different configurations (even the default)
and received the following in an error.txt:
A less error occured trying to build your bundle. You've likely entered an invalid input into the less vari... |
Tried to download a customised setup but css files are empty once downloaded,
the same is true for IE,Safari,FireFox and Chrome. Received a error file with
the downloaded zip, message as follows:
A less error occured trying to build your bundle. You've likely entered an
invalid input into the less variable field. Ch... | 1 |
Since I am tired of getting tons of emails because of Jenkins failing, I tried
to look it up.
======================================================================
ERROR: sklearn.metrics.tests.test_metrics.test_classification_report_multiclass_with_unicode_label
-------------------------------... |
A Test failure on Travis presumably due to changes in lbfgs:
=================================== FAILURES ===================================
________________________________ test_max_iter _________________________________
@ignore_warnings
def test_max_iter():
# Test tha... | 0 |
In our reference documentation, we currently specify what JVM versions are
supported on the setup page:
https://www.elastic.co/guide/en/elasticsearch/reference/current/setup.html
This is just duplicating the information in our support matrix here:
https://www.elastic.co/subscriptions/matrix
Are we worried about t... |
In `/etc/default/elasticsearch` we have `MAX_OPEN_FILES=65535`. If you
uncomment that, but don't edit it, and start ES you get this in the logs;
[2016-04-01 05:02:50,128][WARN ][env ] [Achebe] max file descriptors [65535] for elasticsearch process likely too low, consider increasin... | 0 |
Application: devenv.exe
Framework Version: v4.0.30319
Description: The application requested process termination through System.Environment.FailFast(string message).
Message: System.AggregateException: One or more errors occurred. ---> System.Exception: Error while reading file: 'typescriptSe... |
in `sys.ts` , there are the code
if (typeof WScript !== "undefined" && typeof ActiveXObject === "function") {
return getWScriptSystem();
}
else if (typeof process !== "undefined" && process.nextTick && !process.browser && typeof require !== "undefined") {
... | 0 |
Currently there is no hook that would allow us to set attributes on the node
before it's injected into a document. Which is unfortunate as there are some
attributes in the wild that take effect only before element is injected into a
document.
To workaround this I'm forced to replacing react injected nodes with clone... |
Is there reason why React restricts you to just a subset of DOM elements and
attributes ? Unfortunately it makes it really hard to use it with new HTML or
non standard features unless support for that is added.
I noticed I could create custom elements via `React.createFactory("custom")`
https://github.com/facebook/... | 1 |
I right-clicked on a folder in the tree view
**Atom Version** : 0.194.0
**System** : Windows 7 Entreprise
**Thrown From** : Atom Core
### Stack Trace
Uncaught Error: Cannot find module './context-menu'
Error: Cannot find module './context-menu'
at Function.Module._resolveFilename (module.js:328:15)
at Fu... |
While I admire the simplicity of the installer, it also globs it onto the C
drive without asking. My C drive is a very small SSD, and while Atom isn't
exactly a huge program, I'd prefer to have it on my HDD.
| 0 |
Hello
I want to know if is there a way to disable auto close notification in windows
after generating the notification it will close automatically I can't even set
any timeout for this function
should I use native windows notification?
thanks
|
OS: Windows 8.1 x64
Atom-Shell: 0.19
Sorry for all the editing and deleting of my previous reports but the issue is
morphing and I've narrowed it down. Apparently the webview is garbage
collected when you set it's CSS display property to none. If you do this then
you cannot use the webview again and if you try to ... | 0 |
**Describe the bug**
Duplicate `anon` names used in queries with` union`, `limit` and `joinedload`
causing the query to fail at the driver level.
This query used to work before 1.4.
**To Reproduce**
from sqlalchemy import Column, Integer, String, ForeignKey, PrimaryKeyConstraint, func, Boolean, u... |
Not exactly sure if this is a bug or feature request, but heres what I ran
into.
Attributes of base class cannot be validated from subclasses.
Base = declarative_base()
class Employee(Base):
__tablename__ = 'employee'
id = Column(Integer, primary_key=True)
type =... | 0 |
I'm not 100% sure this is by ES6 spec but the following code errors on Edge
and Firefox Nightly:
new (class extends Promise {
constructor() {
let newThis = this; // Edge: Use before declaration, Firefox: |this| used uninitialized in anonymous class constructor
super((resolve, reje... |
ES6 disallow to use this before super call.
class Aaa {
constructor(v: () => number) {
}
}
class Bbb extends Aaa {
vv: number;
constructor() {
this.vv = 111;
super(this.vvv);
}
vvv(): number { return 0; }
}
The line "this.vv = 111;" ... | 1 |
**Is this a request for help?** (If yes, you should use our troubleshooting
guide and community support channels, see
http://kubernetes.io/docs/troubleshooting/.): No
**What keywords did you search in Kubernetes issues before filing this one?**
(If you have found any duplicates, you should instead reply there.): NA... |
kubedns has resource/limits but not the dnsmasq cache.
| 1 |
It was always like this, no regression, just looks bad

|
When editing Java in Visual Studio Code, import directives are shown with the
package names in blue as if they were keywords. They should be shown in black
because they are identifiers.
| 1 |
Is Electron capable of hosting a socket IO web server? I am currently trying
to connect to my local systems internal IP over my local network (using a port
specified by the Socket.IO server javascript) and my connection is timing out.
|
I've been tracking down a bug in a program that works in OSX but fails
mysteriously in Windows. I've pared down a minimal repro case to the
`net.createConnection` / `net.createServer` APIs w/ a named pipe failing when
run in the main atom process.
If you specify `ATOM_SHELL_INTERNAL_RUN_AS_NODE=1` for both ends of t... | 1 |
##### Issue Type: Bug Report
##### Ansible Version: 1.5.5, 1.6.10, 1.7.1
##### Environment: Ubuntu 12.04 -> Ubuntu 12.04
##### Summary:
The ansible_ssh_user setting does not appear to be applied to a host when
using the delegate_to feature.
##### Steps To Reproduce:
test inventory:
[lb]
lb an... |
##### Issue Type:
Bug Report
##### Ansible Version:
1.6.6
ansible-playbook 1.7 (devel `8e94000`) last updated 2014/07/21 13:14:41 (GMT
-400)
##### Environment:
OSX Mavericks
##### Summary:
Delegating a task should accept that delegated host's ansible_ssh_user
variable. Instead it returns the currently logged... | 1 |
The usual keystroke pattern on a Mac for referencing one of several windows
(as might be open on the left Explorer/Working Files area) is cmd-1, cmd-2,
etc, either from top to bottom or left to right. What would be the proper way
to adjust my settings so that I accomplish this way of selecting windows in
the Working ... |
One of the many hundreds of awesome features of `vi(m)` is the ability to jump
between several lines and do all sorts of things very quickly. However, that's
very difficult to accomplish with the traditional editors.
And this is something I constantly end up missing in VSCode. While there
exists a vim emulation, it... | 0 |
I get the following problem in a Travis build with Typescript 2.2 using
@types/lodash^4.14.45.
node_modules/@types/lodash/index.d.ts(19449,15): error TS2428: All declarations of 'WeakMap' must have identical type parameters.
|
* I tried using the `@types/lodash` package and had problems.
* I tried using the latest stable version of tsc. https://www.npmjs.com/package/typescript
* I have a question that is inappropriate for StackOverflow. (Please ask any appropriate questions there).
* Mention the authors (see `Definitions by:` in `i... | 1 |
Subsets and Splits
No community queries yet
The top public SQL queries from the community will appear here once available.